// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: state.proto
// Protobuf C++ Version: 7.36.0

#ifndef state_2eproto_2epb_2eh
#define state_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7036000
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/unknown_field_set.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_state_2eproto

// Internal implementation detail -- do not use these members.
struct TableStruct_state_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_state_2eproto;
}  // extern "C"
enum DeviceSpecProto_InputSourceType : int;
extern const uint32_t DeviceSpecProto_InputSourceType_internal_data_[];
class BusProto;
struct BusProtoGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern BusProtoGlobalsTypeInternal BusProto_globals_;
extern const ::google::protobuf::internal::ClassDataFull BusProto_class_data_;
#else
extern const BusProtoGlobalsTypeInternal BusProto_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class DeviceSpecProto;
struct DeviceSpecProtoGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern DeviceSpecProtoGlobalsTypeInternal DeviceSpecProto_globals_;
extern const ::google::protobuf::internal::ClassDataFull DeviceSpecProto_class_data_;
#else
extern const DeviceSpecProtoGlobalsTypeInternal DeviceSpecProto_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class InputMappingProto;
struct InputMappingProtoGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern InputMappingProtoGlobalsTypeInternal InputMappingProto_globals_;
extern const ::google::protobuf::internal::ClassDataFull InputMappingProto_class_data_;
#else
extern const InputMappingProtoGlobalsTypeInternal InputMappingProto_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
namespace google {
namespace protobuf {
template <>
internal::EnumTraitsT<::DeviceSpecProto_InputSourceType_internal_data_>
    internal::EnumTraitsImpl::value<::DeviceSpecProto_InputSourceType>;
}  // namespace protobuf
}  // namespace google

enum DeviceSpecProto_InputSourceType : int {
  DeviceSpecProto_InputSourceType_SILENCE = 0,
  DeviceSpecProto_InputSourceType_CAPTURE_CARD = 1,
  DeviceSpecProto_InputSourceType_ALSA_INPUT = 2,
};

extern const uint32_t DeviceSpecProto_InputSourceType_internal_data_[];
inline constexpr DeviceSpecProto_InputSourceType DeviceSpecProto_InputSourceType_InputSourceType_MIN =
    static_cast<DeviceSpecProto_InputSourceType>(0);
inline constexpr DeviceSpecProto_InputSourceType DeviceSpecProto_InputSourceType_InputSourceType_MAX =
    static_cast<DeviceSpecProto_InputSourceType>(2);
[[nodiscard]] inline bool DeviceSpecProto_InputSourceType_IsValid(int value) {
  return 0 <= value && value <= 2;
}
inline constexpr int DeviceSpecProto_InputSourceType_InputSourceType_ARRAYSIZE = 2 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
DeviceSpecProto_InputSourceType_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(DeviceSpecProto_InputSourceType) {
  return DeviceSpecProto_InputSourceType_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& DeviceSpecProto_InputSourceType_Name(T value) {
  static_assert(::std::is_same<T, DeviceSpecProto_InputSourceType>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to InputSourceType_Name().");
  return DeviceSpecProto_InputSourceType_Name(static_cast<DeviceSpecProto_InputSourceType>(value));
}
template <>
[[nodiscard]] inline const ::std::string& DeviceSpecProto_InputSourceType_Name(DeviceSpecProto_InputSourceType value) {
  return ::google::protobuf::internal::NameOfDenseEnum<DeviceSpecProto_InputSourceType_descriptor, 0, 2>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool DeviceSpecProto_InputSourceType_Parse(
    ::absl::string_view name, DeviceSpecProto_InputSourceType* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<DeviceSpecProto_InputSourceType>(DeviceSpecProto_InputSourceType_descriptor(), name,
                                           value);
}
using ::google::protobuf::internal::generated_enum::AbslParseFlag;
using ::google::protobuf::internal::generated_enum::AbslUnparseFlag;

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED DeviceSpecProto final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:DeviceSpecProto) */ {
  using Super_ = ::google::protobuf::Message;

 public:
  inline DeviceSpecProto() : DeviceSpecProto(nullptr) {}
  ~DeviceSpecProto() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(DeviceSpecProto* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(DeviceSpecProto));
  }
#endif

  template <typename = void>
  explicit constexpr DeviceSpecProto(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline DeviceSpecProto(const DeviceSpecProto& from) : DeviceSpecProto(nullptr, from) {}
  inline DeviceSpecProto(DeviceSpecProto&& from) noexcept : DeviceSpecProto(nullptr, ::std::move(from)) {}
  inline DeviceSpecProto& operator=(const DeviceSpecProto& from) {
    CopyFrom(from);
    return *this;
  }
  inline DeviceSpecProto& operator=(DeviceSpecProto&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const DeviceSpecProto& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<DeviceSpecProto>(&DeviceSpecProto_globals_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(DeviceSpecProto& a, DeviceSpecProto& b) { a.Swap(&b); }
  inline void Swap(DeviceSpecProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(DeviceSpecProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] DeviceSpecProto* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return Super_::DefaultConstruct<DeviceSpecProto>(arena);
  }
  using Super_::CopyFrom;
  void CopyFrom(const DeviceSpecProto& from);
  using Super_::MergeFrom;
  void MergeFrom(const DeviceSpecProto& from) { DeviceSpecProto::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(DeviceSpecProto* PROTOBUF_NONNULL other);
 private:
  static ::absl::string_view FullMessageName() { return "DeviceSpecProto"; }

  explicit DeviceSpecProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  DeviceSpecProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const DeviceSpecProto& from);
  DeviceSpecProto(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, DeviceSpecProto&& from) noexcept
      : DeviceSpecProto(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------
  using InputSourceType = DeviceSpecProto_InputSourceType;
  static constexpr InputSourceType SILENCE = DeviceSpecProto_InputSourceType_SILENCE;
  static constexpr InputSourceType CAPTURE_CARD = DeviceSpecProto_InputSourceType_CAPTURE_CARD;
  static constexpr InputSourceType ALSA_INPUT = DeviceSpecProto_InputSourceType_ALSA_INPUT;
  [[nodiscard]] static inline bool InputSourceType_IsValid(int value) {
    return DeviceSpecProto_InputSourceType_IsValid(value);
  }
  static constexpr InputSourceType InputSourceType_MIN = DeviceSpecProto_InputSourceType_InputSourceType_MIN;
  static constexpr InputSourceType InputSourceType_MAX = DeviceSpecProto_InputSourceType_InputSourceType_MAX;
  static constexpr int InputSourceType_ARRAYSIZE = DeviceSpecProto_InputSourceType_InputSourceType_ARRAYSIZE;
  static inline const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL InputSourceType_descriptor() {
    return DeviceSpecProto_InputSourceType_descriptor();
  }
  template <typename T>
  [[nodiscard]] static inline const ::std::string& InputSourceType_Name(T value) {
    return DeviceSpecProto_InputSourceType_Name(value);
  }
  [[nodiscard]] static inline bool InputSourceType_Parse(
      ::absl::string_view name, InputSourceType* PROTOBUF_NONNULL value) {
    return DeviceSpecProto_InputSourceType_Parse(name, value);
  }

  // accessors -------------------------------------------------------
  enum : int {
    kDisplayNameFieldNumber = 3,
    kAlsaNameFieldNumber = 4,
    kAlsaInfoFieldNumber = 5,
    kAddressFieldNumber = 7,
    kTypeFieldNumber = 1,
    kIndexFieldNumber = 2,
    kNumChannelsFieldNumber = 6,
  };
  // optional string display_name = 3;
  [[nodiscard]] bool has_display_name() const;
  void clear_display_name() ;
  [[nodiscard]] const ::std::string& display_name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_display_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_display_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_display_name();
  void set_allocated_display_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_display_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_display_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_display_name();

  public:
  // optional string alsa_name = 4;
  [[nodiscard]] bool has_alsa_name() const;
  void clear_alsa_name() ;
  [[nodiscard]] const ::std::string& alsa_name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_alsa_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_alsa_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_alsa_name();
  void set_allocated_alsa_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_alsa_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_alsa_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_alsa_name();

  public:
  // optional string alsa_info = 5;
  [[nodiscard]] bool has_alsa_info() const;
  void clear_alsa_info() ;
  [[nodiscard]] const ::std::string& alsa_info() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_alsa_info(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_alsa_info();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_alsa_info();
  void set_allocated_alsa_info(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_alsa_info() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_alsa_info(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_alsa_info();

  public:
  // optional string address = 7;
  [[nodiscard]] bool has_address() const;
  void clear_address() ;
  [[nodiscard]] const ::std::string& address() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_address(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_address();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_address();
  void set_allocated_address(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_address() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_address(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_address();

  public:
  // optional .DeviceSpecProto.InputSourceType type = 1;
  [[nodiscard]] bool has_type() const;
  void clear_type() ;
  [[nodiscard]] ::DeviceSpecProto_InputSourceType type() const;
  void set_type(::DeviceSpecProto_InputSourceType value);

  private:
  ::DeviceSpecProto_InputSourceType _internal_type() const;
  void _internal_set_type(::DeviceSpecProto_InputSourceType value);

  public:
  // optional int32 index = 2;
  [[nodiscard]] bool has_index() const;
  void clear_index() ;
  [[nodiscard]] ::int32_t index() const;
  void set_index(::int32_t value);

  private:
  ::int32_t _internal_index() const;
  void _internal_set_index(::int32_t value);

  public:
  // optional int32 num_channels = 6;
  [[nodiscard]] bool has_num_channels() const;
  void clear_num_channels() ;
  [[nodiscard]] ::int32_t num_channels() const;
  void set_num_channels(::int32_t value);

  private:
  ::int32_t _internal_num_channels() const;
  void _internal_set_num_channels(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:DeviceSpecProto)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 7,
                          1, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const DeviceSpecProto& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr display_name_;
    ::google::protobuf::internal::ArenaStringPtr alsa_name_;
    ::google::protobuf::internal::ArenaStringPtr alsa_info_;
    ::google::protobuf::internal::ArenaStringPtr address_;
    int type_;
    ::int32_t index_;
    ::int32_t num_channels_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_state_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED BusProto final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:BusProto) */ {
  using Super_ = ::google::protobuf::Message;

 public:
  inline BusProto() : BusProto(nullptr) {}
  ~BusProto() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(BusProto* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(BusProto));
  }
#endif

  template <typename = void>
  explicit constexpr BusProto(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline BusProto(const BusProto& from) : BusProto(nullptr, from) {}
  inline BusProto(BusProto&& from) noexcept : BusProto(nullptr, ::std::move(from)) {}
  inline BusProto& operator=(const BusProto& from) {
    CopyFrom(from);
    return *this;
  }
  inline BusProto& operator=(BusProto&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const BusProto& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<BusProto>(&BusProto_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(BusProto& a, BusProto& b) { a.Swap(&b); }
  inline void Swap(BusProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(BusProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] BusProto* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return Super_::DefaultConstruct<BusProto>(arena);
  }
  using Super_::CopyFrom;
  void CopyFrom(const BusProto& from);
  using Super_::MergeFrom;
  void MergeFrom(const BusProto& from) { BusProto::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(BusProto* PROTOBUF_NONNULL other);
 private:
  static ::absl::string_view FullMessageName() { return "BusProto"; }

  explicit BusProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  BusProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const BusProto& from);
  BusProto(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, BusProto&& from) noexcept
      : BusProto(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kNameFieldNumber = 1,
    kDeviceIndexFieldNumber = 2,
    kSourceChannelLeftFieldNumber = 3,
    kSourceChannelRightFieldNumber = 4,
  };
  // optional string name = 1;
  [[nodiscard]] bool has_name() const;
  void clear_name() ;
  [[nodiscard]] const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // optional int32 device_index = 2;
  [[nodiscard]] bool has_device_index() const;
  void clear_device_index() ;
  [[nodiscard]] ::int32_t device_index() const;
  void set_device_index(::int32_t value);

  private:
  ::int32_t _internal_device_index() const;
  void _internal_set_device_index(::int32_t value);

  public:
  // optional int32 source_channel_left = 3;
  [[nodiscard]] bool has_source_channel_left() const;
  void clear_source_channel_left() ;
  [[nodiscard]] ::int32_t source_channel_left() const;
  void set_source_channel_left(::int32_t value);

  private:
  ::int32_t _internal_source_channel_left() const;
  void _internal_set_source_channel_left(::int32_t value);

  public:
  // optional int32 source_channel_right = 4;
  [[nodiscard]] bool has_source_channel_right() const;
  void clear_source_channel_right() ;
  [[nodiscard]] ::int32_t source_channel_right() const;
  void set_source_channel_right(::int32_t value);

  private:
  ::int32_t _internal_source_channel_right() const;
  void _internal_set_source_channel_right(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:BusProto)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 4,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const BusProto& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    ::int32_t device_index_;
    ::int32_t source_channel_left_;
    ::int32_t source_channel_right_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_state_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED InputMappingProto final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:InputMappingProto) */ {
  using Super_ = ::google::protobuf::Message;

 public:
  inline InputMappingProto() : InputMappingProto(nullptr) {}
  ~InputMappingProto() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(InputMappingProto* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(InputMappingProto));
  }
#endif

  template <typename = void>
  explicit constexpr InputMappingProto(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline InputMappingProto(const InputMappingProto& from) : InputMappingProto(nullptr, from) {}
  inline InputMappingProto(InputMappingProto&& from) noexcept : InputMappingProto(nullptr, ::std::move(from)) {}
  inline InputMappingProto& operator=(const InputMappingProto& from) {
    CopyFrom(from);
    return *this;
  }
  inline InputMappingProto& operator=(InputMappingProto&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const InputMappingProto& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<InputMappingProto>(&InputMappingProto_globals_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(InputMappingProto& a, InputMappingProto& b) { a.Swap(&b); }
  inline void Swap(InputMappingProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(InputMappingProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] InputMappingProto* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return Super_::DefaultConstruct<InputMappingProto>(arena);
  }
  using Super_::CopyFrom;
  void CopyFrom(const InputMappingProto& from);
  using Super_::MergeFrom;
  void MergeFrom(const InputMappingProto& from) { InputMappingProto::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(InputMappingProto* PROTOBUF_NONNULL other);
 private:
  static ::absl::string_view FullMessageName() { return "InputMappingProto"; }

  explicit InputMappingProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  InputMappingProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const InputMappingProto& from);
  InputMappingProto(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, InputMappingProto&& from) noexcept
      : InputMappingProto(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kDeviceFieldNumber = 1,
    kBusFieldNumber = 2,
  };
  // repeated .DeviceSpecProto device = 1;
  [[nodiscard]] int device_size() const;
  private:
  int _internal_device_size() const;

  public:
  void clear_device() ;
  [[nodiscard]] const ::DeviceSpecProto& device(int index) const;
  [[nodiscard]] ::DeviceSpecProto* PROTOBUF_NONNULL mutable_device(int index);
  ::DeviceSpecProto* PROTOBUF_NONNULL add_device();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>&
  device() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>* PROTOBUF_NONNULL
  mutable_device();

  private:
  const ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>& _internal_device() const;
  ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>* PROTOBUF_NONNULL _internal_mutable_device();

  public:
  // repeated .BusProto bus = 2;
  [[nodiscard]] int bus_size() const;
  private:
  int _internal_bus_size() const;

  public:
  void clear_bus() ;
  [[nodiscard]] const ::BusProto& bus(int index) const;
  [[nodiscard]] ::BusProto* PROTOBUF_NONNULL mutable_bus(int index);
  ::BusProto* PROTOBUF_NONNULL add_bus();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::BusProto>&
  bus() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::BusProto>* PROTOBUF_NONNULL
  mutable_bus();

  private:
  const ::google::protobuf::RepeatedPtrField<::BusProto>& _internal_bus() const;
  ::google::protobuf::RepeatedPtrField<::BusProto>* PROTOBUF_NONNULL _internal_mutable_bus();

  public:
  // @@protoc_insertion_point(class_scope:InputMappingProto)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<1, 2,
                          2, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const InputMappingProto& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::DeviceSpecProto > device_;
    ::google::protobuf::RepeatedPtrField< ::BusProto > bus_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_state_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// DeviceSpecProto

// optional .DeviceSpecProto.InputSourceType type = 1;
inline bool DeviceSpecProto::has_type() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000010U);
  return value;
}
inline void DeviceSpecProto::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline ::DeviceSpecProto_InputSourceType DeviceSpecProto::type() const {
  // @@protoc_insertion_point(field_get:DeviceSpecProto.type)
  return _internal_type();
}
inline void DeviceSpecProto::set_type(::DeviceSpecProto_InputSourceType value) {
  _internal_set_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:DeviceSpecProto.type)
}
inline ::DeviceSpecProto_InputSourceType DeviceSpecProto::_internal_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::DeviceSpecProto_InputSourceType>(_impl_.type_);
}
inline void DeviceSpecProto::_internal_set_type(::DeviceSpecProto_InputSourceType value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);

                                          assert(::google::protobuf::internal::ValidateEnum(
                                              value, ::DeviceSpecProto_InputSourceType_internal_data_));
                                          _impl_.type_ = value;
}

// optional int32 index = 2;
inline bool DeviceSpecProto::has_index() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000020U);
  return value;
}
inline void DeviceSpecProto::clear_index() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.index_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
}
inline ::int32_t DeviceSpecProto::index() const {
  // @@protoc_insertion_point(field_get:DeviceSpecProto.index)
  return _internal_index();
}
inline void DeviceSpecProto::set_index(::int32_t value) {
  _internal_set_index(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  // @@protoc_insertion_point(field_set:DeviceSpecProto.index)
}
inline ::int32_t DeviceSpecProto::_internal_index() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.index_;
}
inline void DeviceSpecProto::_internal_set_index(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.index_ = value;
}

// optional string display_name = 3;
inline bool DeviceSpecProto::has_display_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void DeviceSpecProto::clear_display_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.display_name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& DeviceSpecProto::display_name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:DeviceSpecProto.display_name)
  return _internal_display_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void DeviceSpecProto::set_display_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.display_name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:DeviceSpecProto.display_name)
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::mutable_display_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_display_name();
  // @@protoc_insertion_point(field_mutable:DeviceSpecProto.display_name)
  return _s;
}
inline const ::std::string& DeviceSpecProto::_internal_display_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.display_name_.Get();
}
inline void DeviceSpecProto::_internal_set_display_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.display_name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::_internal_mutable_display_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.display_name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE DeviceSpecProto::release_display_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:DeviceSpecProto.display_name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.display_name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.display_name_.Set("", GetArena());
  }
  return released;
}
inline void DeviceSpecProto::set_allocated_display_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.display_name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.display_name_.IsDefault()) {
    _impl_.display_name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:DeviceSpecProto.display_name)
}

// optional string alsa_name = 4;
inline bool DeviceSpecProto::has_alsa_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void DeviceSpecProto::clear_alsa_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alsa_name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& DeviceSpecProto::alsa_name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:DeviceSpecProto.alsa_name)
  return _internal_alsa_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void DeviceSpecProto::set_alsa_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.alsa_name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:DeviceSpecProto.alsa_name)
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::mutable_alsa_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_alsa_name();
  // @@protoc_insertion_point(field_mutable:DeviceSpecProto.alsa_name)
  return _s;
}
inline const ::std::string& DeviceSpecProto::_internal_alsa_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.alsa_name_.Get();
}
inline void DeviceSpecProto::_internal_set_alsa_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alsa_name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::_internal_mutable_alsa_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.alsa_name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE DeviceSpecProto::release_alsa_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:DeviceSpecProto.alsa_name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.alsa_name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.alsa_name_.Set("", GetArena());
  }
  return released;
}
inline void DeviceSpecProto::set_allocated_alsa_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.alsa_name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.alsa_name_.IsDefault()) {
    _impl_.alsa_name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:DeviceSpecProto.alsa_name)
}

// optional string alsa_info = 5;
inline bool DeviceSpecProto::has_alsa_info() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void DeviceSpecProto::clear_alsa_info() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alsa_info_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline const ::std::string& DeviceSpecProto::alsa_info() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:DeviceSpecProto.alsa_info)
  return _internal_alsa_info();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void DeviceSpecProto::set_alsa_info(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  _impl_.alsa_info_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:DeviceSpecProto.alsa_info)
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::mutable_alsa_info()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::std::string* _s = _internal_mutable_alsa_info();
  // @@protoc_insertion_point(field_mutable:DeviceSpecProto.alsa_info)
  return _s;
}
inline const ::std::string& DeviceSpecProto::_internal_alsa_info() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.alsa_info_.Get();
}
inline void DeviceSpecProto::_internal_set_alsa_info(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alsa_info_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::_internal_mutable_alsa_info() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.alsa_info_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE DeviceSpecProto::release_alsa_info() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:DeviceSpecProto.alsa_info)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000004U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  auto* released = _impl_.alsa_info_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.alsa_info_.Set("", GetArena());
  }
  return released;
}
inline void DeviceSpecProto::set_allocated_alsa_info(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  _impl_.alsa_info_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.alsa_info_.IsDefault()) {
    _impl_.alsa_info_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:DeviceSpecProto.alsa_info)
}

// optional int32 num_channels = 6;
inline bool DeviceSpecProto::has_num_channels() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000040U);
  return value;
}
inline void DeviceSpecProto::clear_num_channels() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.num_channels_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000040U);
}
inline ::int32_t DeviceSpecProto::num_channels() const {
  // @@protoc_insertion_point(field_get:DeviceSpecProto.num_channels)
  return _internal_num_channels();
}
inline void DeviceSpecProto::set_num_channels(::int32_t value) {
  _internal_set_num_channels(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  // @@protoc_insertion_point(field_set:DeviceSpecProto.num_channels)
}
inline ::int32_t DeviceSpecProto::_internal_num_channels() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.num_channels_;
}
inline void DeviceSpecProto::_internal_set_num_channels(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.num_channels_ = value;
}

// optional string address = 7;
inline bool DeviceSpecProto::has_address() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  return value;
}
inline void DeviceSpecProto::clear_address() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.address_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline const ::std::string& DeviceSpecProto::address() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:DeviceSpecProto.address)
  return _internal_address();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void DeviceSpecProto::set_address(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  _impl_.address_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:DeviceSpecProto.address)
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::mutable_address()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::std::string* _s = _internal_mutable_address();
  // @@protoc_insertion_point(field_mutable:DeviceSpecProto.address)
  return _s;
}
inline const ::std::string& DeviceSpecProto::_internal_address() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.address_.Get();
}
inline void DeviceSpecProto::_internal_set_address(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.address_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL DeviceSpecProto::_internal_mutable_address() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.address_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE DeviceSpecProto::release_address() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:DeviceSpecProto.address)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000008U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  auto* released = _impl_.address_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.address_.Set("", GetArena());
  }
  return released;
}
inline void DeviceSpecProto::set_allocated_address(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  _impl_.address_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.address_.IsDefault()) {
    _impl_.address_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:DeviceSpecProto.address)
}

// -------------------------------------------------------------------

// BusProto

// optional string name = 1;
inline bool BusProto::has_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void BusProto::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& BusProto::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:BusProto.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void BusProto::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:BusProto.name)
}
inline ::std::string* PROTOBUF_NONNULL BusProto::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:BusProto.name)
  return _s;
}
inline const ::std::string& BusProto::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void BusProto::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL BusProto::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE BusProto::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:BusProto.name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void BusProto::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:BusProto.name)
}

// optional int32 device_index = 2;
inline bool BusProto::has_device_index() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void BusProto::clear_device_index() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.device_index_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline ::int32_t BusProto::device_index() const {
  // @@protoc_insertion_point(field_get:BusProto.device_index)
  return _internal_device_index();
}
inline void BusProto::set_device_index(::int32_t value) {
  _internal_set_device_index(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:BusProto.device_index)
}
inline ::int32_t BusProto::_internal_device_index() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.device_index_;
}
inline void BusProto::_internal_set_device_index(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.device_index_ = value;
}

// optional int32 source_channel_left = 3;
inline bool BusProto::has_source_channel_left() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void BusProto::clear_source_channel_left() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.source_channel_left_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline ::int32_t BusProto::source_channel_left() const {
  // @@protoc_insertion_point(field_get:BusProto.source_channel_left)
  return _internal_source_channel_left();
}
inline void BusProto::set_source_channel_left(::int32_t value) {
  _internal_set_source_channel_left(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:BusProto.source_channel_left)
}
inline ::int32_t BusProto::_internal_source_channel_left() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.source_channel_left_;
}
inline void BusProto::_internal_set_source_channel_left(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.source_channel_left_ = value;
}

// optional int32 source_channel_right = 4;
inline bool BusProto::has_source_channel_right() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  return value;
}
inline void BusProto::clear_source_channel_right() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.source_channel_right_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline ::int32_t BusProto::source_channel_right() const {
  // @@protoc_insertion_point(field_get:BusProto.source_channel_right)
  return _internal_source_channel_right();
}
inline void BusProto::set_source_channel_right(::int32_t value) {
  _internal_set_source_channel_right(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_set:BusProto.source_channel_right)
}
inline ::int32_t BusProto::_internal_source_channel_right() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.source_channel_right_;
}
inline void BusProto::_internal_set_source_channel_right(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.source_channel_right_ = value;
}

// -------------------------------------------------------------------

// InputMappingProto

// repeated .DeviceSpecProto device = 1;
inline int InputMappingProto::_internal_device_size() const {
  return _internal_device().size();
}
inline int InputMappingProto::device_size() const {
  return _internal_device_size();
}
inline void InputMappingProto::clear_device() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.device_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::DeviceSpecProto& InputMappingProto::device(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:InputMappingProto.device)
  return _internal_device().Get(index);
}
inline ::DeviceSpecProto* PROTOBUF_NONNULL InputMappingProto::mutable_device(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:InputMappingProto.device)
  return _internal_mutable_device()->Mutable(index);
}
inline ::DeviceSpecProto* PROTOBUF_NONNULL InputMappingProto::add_device()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::DeviceSpecProto* _add =
      _internal_mutable_device()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:InputMappingProto.device)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>& InputMappingProto::device() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:InputMappingProto.device)
  return _internal_device();
}
inline ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>* PROTOBUF_NONNULL
InputMappingProto::mutable_device() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:InputMappingProto.device)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_device();
}
inline const ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>&
InputMappingProto::_internal_device() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.device_;
}
inline ::google::protobuf::RepeatedPtrField<::DeviceSpecProto>* PROTOBUF_NONNULL
InputMappingProto::_internal_mutable_device() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.device_;
}

// repeated .BusProto bus = 2;
inline int InputMappingProto::_internal_bus_size() const {
  return _internal_bus().size();
}
inline int InputMappingProto::bus_size() const {
  return _internal_bus_size();
}
inline void InputMappingProto::clear_bus() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.bus_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::BusProto& InputMappingProto::bus(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:InputMappingProto.bus)
  return _internal_bus().Get(index);
}
inline ::BusProto* PROTOBUF_NONNULL InputMappingProto::mutable_bus(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:InputMappingProto.bus)
  return _internal_mutable_bus()->Mutable(index);
}
inline ::BusProto* PROTOBUF_NONNULL InputMappingProto::add_bus()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::BusProto* _add =
      _internal_mutable_bus()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_add:InputMappingProto.bus)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::BusProto>& InputMappingProto::bus() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:InputMappingProto.bus)
  return _internal_bus();
}
inline ::google::protobuf::RepeatedPtrField<::BusProto>* PROTOBUF_NONNULL
InputMappingProto::mutable_bus() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_mutable_list:InputMappingProto.bus)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_bus();
}
inline const ::google::protobuf::RepeatedPtrField<::BusProto>&
InputMappingProto::_internal_bus() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.bus_;
}
inline ::google::protobuf::RepeatedPtrField<::BusProto>* PROTOBUF_NONNULL
InputMappingProto::_internal_mutable_bus() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.bus_;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::DeviceSpecProto_InputSourceType> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::DeviceSpecProto_InputSourceType>() {
  return ::DeviceSpecProto_InputSourceType_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // state_2eproto_2epb_2eh
